@@ -2,12 +2,6 @@
 
 {- | This module is highly experimental! -}
 
-{-
-It seems that in GHC 6.11 StringRep has been renamed CharRep.
-Please rename the two occurences StringRep if using GHC >= 6.11.
-Thanks to David Duke for this.
--}
-
 module Test.LazySmallCheck.Generic
   ( depthCheck  -- :: (Data a, Show a) => Int -> (a -> Bool) -> IO [a]
   , (==>)       -- :: Bool -> Bool -> Bool
@@ -49,9 +43,9 @@ refinePData s d = r
                                  if   ncon == 0
                                  then Just x'
                                  else Nothing) xs'
-         IntRep -> mkPrim dt (mkIntConstr dt . toInteger)
+         IntRep -> mkPrim dt (mkIntegralConstr dt . toInteger)
                              [-depleft .. depleft]
-         StringRep -> mkPrim dt (mkStringConstr dt . (:[]))
+         CharRep -> mkPrim dt (mkCharConstr dt)
                                 (take (depleft+1) ['a' .. 'z'])
          _ -> error $ "LazySmallCheck.Generic: Can't generate type "
                    ++ dataTypeName dt
@@ -98,8 +92,8 @@ enumerate d = result
      cons' :: [Constr]
      cons' = case dataTypeRep ty of
               AlgRep cons -> cons
-              IntRep      -> map (mkIntConstr ty . toInteger) [-d .. d]
-              StringRep   -> map (mkStringConstr ty . (:[])) (take d ['a'..'z'])
+              IntRep      -> map (mkIntegralConstr ty . toInteger) [-d .. d]
+              CharRep     -> map (mkCharConstr ty) (take d ['a'..'z'])
               --FloatRep  ->
       where
         ty = dataTypeOf (head result)     
